@@ -1,7 +1,7 @@
 import subprocess
 
 def ola_milene():
-    resultado = subprocess.check_output(["./ola_milene"])
+    resultado = subprocess.check_output(["./pythonce/OlaMi"])
 
     resultado_str = resultado.decode("utf-8")
 
