@@ -7,13 +7,11 @@ def executar_programa_c():
 
 def somar(x, y):
     resultado = subprocess.run(['./pythonce/soma', str(x), str(y)], capture_output=True, text=True)
-    if resultado.returncode != 0:
-        print("Erro ao executar o programa")
-        return None
-    else:
-        return resultado.stdout.strip()
+    return resultado.stdout.strip()
     
-def olaMi():
-    resultado = subprocess.run(['./pythonce/OlaMi'], capture_output=True, text=True)
-    saida = resultado.stdout.strip()
-    return saida
+def ola_milene():
+    resultado = subprocess.check_output(["./pythonce/OlaMi"])
+
+    resultado_str = resultado.decode("utf-8")
+
+    return resultado_str
\ No newline at end of file
