@@ -1,4 +1,5 @@
 #include <stdio.h>
+#include <stdlib.h>
 
 int soma(int a, int b) {
     return a + b;
@@ -17,7 +18,7 @@ int main(int argc, char *argv[]) {
 
     resultado = soma(x, y);
 
-    printf("%d\n", resultado);
+    printf("%d\n", (int)resultado);
 
     return 0;
 }
